"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_native_1 = require("react-native");
var bridge = react_native_1.NativeModules.ReactNativeBiometrics;
var ReactNativeBiometrics;
(function (ReactNativeBiometrics) {
    /**
     * Enum for touch id sensor type
     */
    ReactNativeBiometrics.TouchID = 'TouchID';
    /**
     * Enum for face id sensor type
     */
    ReactNativeBiometrics.FaceID = 'FaceID';
    /**
     * Enum for generic biometrics (this is the only value available on android)
     */
    ReactNativeBiometrics.Biometrics = 'Biometrics';
    /**
     * Returns promise that resolves to an object with object.biometryType = Biometrics | TouchID | FaceID
     * @param {Object} isSensorAvailableOptions
     * @param {boolean} isSensorAvailableOptions.allowDeviceCredentials
     * @returns {Promise<Object>} Promise that resolves to an object with details about biometrics available
     */
    function isSensorAvailable(isSensorAvailableOptions) {
        var _a, _b;
        var options = {
            allowDeviceCredentials: (_b = (_a = isSensorAvailableOptions) === null || _a === void 0 ? void 0 : _a.allowDeviceCredentials, (_b !== null && _b !== void 0 ? _b : false))
        };
        return bridge.isSensorAvailable(options);
    }
    ReactNativeBiometrics.isSensorAvailable = isSensorAvailable;
    /**
     * Creates a public private key pair,returns promise that resolves to
     * an object with object.publicKey, which is the public key of the newly generated key pair
     * @param {Object} createKeysOptions
     * @param {boolean} createKeysOptions.allowDeviceCredentials
     * @returns {Promise<Object>}  Promise that resolves to object with details about the newly generated public key
     */
    function createKeys(createKeysOptions) {
        var _a, _b;
        var options = {
            allowDeviceCredentials: (_b = (_a = createKeysOptions) === null || _a === void 0 ? void 0 : _a.allowDeviceCredentials, (_b !== null && _b !== void 0 ? _b : false))
        };
        return bridge.createKeys(options);
    }
    ReactNativeBiometrics.createKeys = createKeys;
    /**
     * Returns promise that resolves to an object with object.keysExists = true | false
     * indicating if the keys were found to exist or not
     * @returns {Promise<Object>} Promise that resolves to object with details aobut the existence of keys
     */
    function biometricKeysExist() {
        return bridge.biometricKeysExist();
    }
    ReactNativeBiometrics.biometricKeysExist = biometricKeysExist;
    /**
     * Returns promise that resolves to an object with true | false
     * indicating if the keys were properly deleted
     * @returns {Promise<Object>} Promise that resolves to an object with details about the deletion
     */
    function deleteKeys() {
        return bridge.deleteKeys();
    }
    ReactNativeBiometrics.deleteKeys = deleteKeys;
    /**
     * Prompts user with biometrics dialog using the passed in prompt message and
     * returns promise that resolves to an object with object.signature,
     * which is cryptographic signature of the payload
     * @param {Object} createSignatureOptions
     * @param {string} createSignatureOptions.promptMessage
     * @param {string} createSignatureOptions.payload
     * @param {boolean} createSignatureOptions.allowDeviceCredentials
     * @returns {Promise<Object>}  Promise that resolves to an object cryptographic signature details
     */
    function createSignature(createSignatureOptions) {
        var _a, _b;
        createSignatureOptions.cancelButtonText = (_a = createSignatureOptions.cancelButtonText, (_a !== null && _a !== void 0 ? _a : 'Cancel'));
        createSignatureOptions.allowDeviceCredentials = (_b = createSignatureOptions.allowDeviceCredentials, (_b !== null && _b !== void 0 ? _b : false));
        return bridge.createSignature(createSignatureOptions);
    }
    ReactNativeBiometrics.createSignature = createSignature;
    /**
     * Prompts user with biometrics dialog using the passed in prompt message and
     * returns promise that resolves to an object with object.success = true if the user passes,
     * object.success = false if the user cancels, and rejects if anything fails
     * @param {Object} simplePromptOptions
     * @param {string} simplePromptOptions.promptMessage
     * @param {string} simplePromptOptions.fallbackPromptMessage
     * @param {boolean} simplePromptOptions.allowDeviceCredentials
     * @returns {Promise<Object>}  Promise that resolves an object with details about the biometrics result
     */
    function simplePrompt(simplePromptOptions) {
        var _a, _b, _c;
        simplePromptOptions.cancelButtonText = (_a = simplePromptOptions.cancelButtonText, (_a !== null && _a !== void 0 ? _a : 'Cancel'));
        simplePromptOptions.fallbackPromptMessage = (_b = simplePromptOptions.fallbackPromptMessage, (_b !== null && _b !== void 0 ? _b : 'Use Passcode'));
        simplePromptOptions.allowDeviceCredentials = (_c = simplePromptOptions.allowDeviceCredentials, (_c !== null && _c !== void 0 ? _c : false));
        return bridge.simplePrompt(simplePromptOptions);
    }
    ReactNativeBiometrics.simplePrompt = simplePrompt;
})(ReactNativeBiometrics || (ReactNativeBiometrics = {}));
exports.default = ReactNativeBiometrics;
//# sourceMappingURL=index.js.map